document.addEventListener('DOMContentLoaded', () => {
  const urlInput = document.getElementById('urlInput');
  const captureBtn = document.getElementById('captureBtn');
  const loading = document.getElementById('loading');
  const screenshotImg = document.getElementById('screenshotImg');
  const downloadBtn = document.getElementById('downloadBtn');

  captureBtn.addEventListener('click', async () => {
    const url = urlInput.value.trim();
    
    if (!url) {
      alert('Please enter a valid URL');
      return;
    }

    try {
      // Show loading state
      loading.style.display = 'block';
      screenshotImg.hidden = true;
      downloadBtn.hidden = true;

      // In a real implementation, this would call a screenshot API
      // For demo purposes, we'll simulate a delay and show a placeholder
      await new Promise(resolve => setTimeout(resolve, 2000));
      
      // Simulate screenshot result
      screenshotImg.src = `data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="800" height="400"><rect width="100%" height="100%" fill="%232563eb"/><text x="50%" y="50%" font-family="Arial" font-size="24" fill="white" text-anchor="middle">Screenshot of ${url}</text></svg>`;
      
      // Show results
      loading.style.display = 'none';
      screenshotImg.hidden = false;
      downloadBtn.hidden = false;

    } catch (error) {
      alert('Error capturing screenshot. Please try again.');
      loading.style.display = 'none';
    }
  });

  downloadBtn.addEventListener('click', () => {
    // In a real implementation, this would download the actual screenshot
    const link = document.createElement('a');
    link.download = 'screenshot.png';
    link.href = screenshotImg.src;
    link.click();
  });

  // Enable form submission with Enter key
  urlInput.addEventListener('keypress', (e) => {
    if (e.key === 'Enter') {
      captureBtn.click();
    }
  });
});
